summaryrefslogtreecommitdiffstats
path: root/kdevdesigner/designer/variabledialogimpl.cpp
diff options
context:
space:
mode:
Diffstat (limited to 'kdevdesigner/designer/variabledialogimpl.cpp')
-rw-r--r--kdevdesigner/designer/variabledialogimpl.cpp16
1 files changed, 8 insertions, 8 deletions
diff --git a/kdevdesigner/designer/variabledialogimpl.cpp b/kdevdesigner/designer/variabledialogimpl.cpp
index 19af5e6c..bd0ef745 100644
--- a/kdevdesigner/designer/variabledialogimpl.cpp
+++ b/kdevdesigner/designer/variabledialogimpl.cpp
@@ -1,15 +1,15 @@
/**********************************************************************
** Copyright (C) 2000-2001 Trolltech AS. All rights reserved.
**
** This file is part of Qt Designer.
**
** This file may be distributed and/or modified under the terms of the
** GNU General Public License version 2 as published by the Free Software
** Foundation and appearing in the file LICENSE.GPL included in the
** packaging of this file.
**
-** Licensees holding valid Qt Enterprise Edition or Qt Professional Edition
-** licenses may use this file in accordance with the Qt Commercial License
+** Licensees holding valid TQt Enterprise Edition or TQt Professional Edition
+** licenses may use this file in accordance with the TQt Commercial License
** Agreement provided with the Software.
**
** This file is provided AS IS with NO WARRANTY OF ANY KIND, INCLUDING THE
@@ -17,7 +17,7 @@
**
** See http://www.trolltech.com/gpl/ for GPL licensing information.
** See http://www.trolltech.com/pricing.html or email sales@trolltech.com for
-** information about Qt Commercial License Agreements.
+** information about TQt Commercial License Agreements.
**
** Contact info@trolltech.com if any conditions of this licensing are
** not clear to you.
@@ -40,11 +40,11 @@
#include <klocale.h>
-VariableDialog::VariableDialog( FormWindow *fw, TQWidget *parent )
- : VariableDialogBase( parent ), formWindow( fw )
+VariableDialog::VariableDialog( FormWindow *fw, TQWidget *tqparent )
+ : VariableDialogBase( tqparent ), formWindow( fw )
{
varView->setSorting( -1 );
- TQValueList<MetaDataBase::Variable> varLst = MetaDataBase::variables( formWindow );
+ TQValueList<MetaDataBase::Variable> varLst = MetaDataBase::variables( TQT_TQOBJECT(formWindow) );
TQValueList<MetaDataBase::Variable>::Iterator it = varLst.begin();
for ( ; it != varLst.end(); ++it ) {
TQListViewItem *i = new TQListViewItem( varView );
@@ -64,7 +64,7 @@ VariableDialog::~VariableDialog()
void VariableDialog::setCurrentItem( TQString text )
{
- TQListViewItem *i = varView->findItem( text, 0 );
+ TQListViewItem *i = varView->tqfindItem( text, 0 );
if ( i )
varView->setCurrentItem( i );
}
@@ -1,15 +1,15 @@
** Copyright (C) 2000-2001 Trolltech AS. All rights reserved.
**
-** This file is part of Qt Designer.
+** This file is part of TQt Designer.
**
** This file may be distributed and/or modified under the terms of the